/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GroupAccessTokenConfig extends cdktf.TerraformMetaArguments {
    /**
    * The access level for the group access token. Valid values are: `no one`, `minimal`, `guest`, `reporter`, `developer`, `maintainer`, `owner`. Default is `maintainer`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/gitlabhq/gitlab/17.9.0/docs/resources/group_access_token#access_level GroupAccessToken#access_level}
    */
    readonly accessLevel?: string;
    /**
    * When the token will expire, YYYY-MM-DD format.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/gitlabhq/gitlab/17.9.0/docs/resources/group_access_token#expires_at GroupAccessToken#expires_at}
    */
    readonly expiresAt?: string;
    /**
    * The ID or full path of the group.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/gitlabhq/gitlab/17.9.0/docs/resources/group_access_token#group GroupAccessToken#group}
    */
    readonly group: string;
    /**
    * The name of the group access token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/gitlabhq/gitlab/17.9.0/docs/resources/group_access_token#name GroupAccessToken#name}
    */
    readonly name: string;
    /**
    * The configuration for when to rotate a token automatically. Will not rotate a token until `terraform apply` is run.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/gitlabhq/gitlab/17.9.0/docs/resources/group_access_token#rotation_configuration GroupAccessToken#rotation_configuration}
    */
    readonly rotationConfiguration?: GroupAccessTokenRotationConfiguration;
    /**
    * The scopes of the group access token. Valid values are: `api`, `read_api`, `read_registry`, `write_registry`, `read_repository`, `write_repository`, `create_runner`, `manage_runner`, `ai_features`, `k8s_proxy`, `read_observability`, `write_observability`
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/gitlabhq/gitlab/17.9.0/docs/resources/group_access_token#scopes GroupAccessToken#scopes}
    */
    readonly scopes: string[];
}
export interface GroupAccessTokenRotationConfiguration {
    /**
    * The duration (in days) the new token should be valid for.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/gitlabhq/gitlab/17.9.0/docs/resources/group_access_token#expiration_days GroupAccessToken#expiration_days}
    */
    readonly expirationDays: number;
    /**
    * The duration (in days) before the expiration when the token should be rotated. As an example, if set to 7 days, the token will rotate 7 days before the expiration date, but only when `terraform apply` is run in that timeframe.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/gitlabhq/gitlab/17.9.0/docs/resources/group_access_token#rotate_before_days GroupAccessToken#rotate_before_days}
    */
    readonly rotateBeforeDays: number;
}
export declare function groupAccessTokenRotationConfigurationToTerraform(struct?: GroupAccessTokenRotationConfiguration | cdktf.IResolvable): any;
export declare function groupAccessTokenRotationConfigurationToHclTerraform(struct?: GroupAccessTokenRotationConfiguration | cdktf.IResolvable): any;
export declare class GroupAccessTokenRotationConfigurationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GroupAccessTokenRotationConfiguration | cdktf.IResolvable | undefined;
    set internalValue(value: GroupAccessTokenRotationConfiguration | cdktf.IResolvable | undefined);
    private _expirationDays?;
    get expirationDays(): number;
    set expirationDays(value: number);
    get expirationDaysInput(): number | undefined;
    private _rotateBeforeDays?;
    get rotateBeforeDays(): number;
    set rotateBeforeDays(value: number);
    get rotateBeforeDaysInput(): number | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/gitlabhq/gitlab/17.9.0/docs/resources/group_access_token gitlab_group_access_token}
*/
export declare class GroupAccessToken extends cdktf.TerraformResource {
    static readonly tfResourceType = "gitlab_group_access_token";
    /**
    * Generates CDKTF code for importing a GroupAccessToken resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the GroupAccessToken to import
    * @param importFromId The id of the existing GroupAccessToken that should be imported. Refer to the {@link https://registry.terraform.io/providers/gitlabhq/gitlab/17.9.0/docs/resources/group_access_token#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the GroupAccessToken to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/gitlabhq/gitlab/17.9.0/docs/resources/group_access_token gitlab_group_access_token} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GroupAccessTokenConfig
    */
    constructor(scope: Construct, id: string, config: GroupAccessTokenConfig);
    private _accessLevel?;
    get accessLevel(): string;
    set accessLevel(value: string);
    resetAccessLevel(): void;
    get accessLevelInput(): string | undefined;
    get active(): cdktf.IResolvable;
    get createdAt(): string;
    private _expiresAt?;
    get expiresAt(): string;
    set expiresAt(value: string);
    resetExpiresAt(): void;
    get expiresAtInput(): string | undefined;
    private _group?;
    get group(): string;
    set group(value: string);
    get groupInput(): string | undefined;
    get id(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get revoked(): cdktf.IResolvable;
    private _rotationConfiguration;
    get rotationConfiguration(): GroupAccessTokenRotationConfigurationOutputReference;
    putRotationConfiguration(value: GroupAccessTokenRotationConfiguration): void;
    resetRotationConfiguration(): void;
    get rotationConfigurationInput(): cdktf.IResolvable | GroupAccessTokenRotationConfiguration | undefined;
    private _scopes?;
    get scopes(): string[];
    set scopes(value: string[]);
    get scopesInput(): string[] | undefined;
    get token(): string;
    get userId(): number;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
